@@ -33,6 +33,11 @@
 
 #include <stdbool.h>
 
+#ifdef HAVE_W32_SYSTEM
+#define __USE_W32_SOCKETS 1
+#include <windows.h>
+#endif
+
 #include <assuan.h>
 #include <gpg-error.h>
 
@@ -49,13 +54,17 @@
 CK_DEFINE_FUNCTION(CK_RV, C_Initialize) (CK_VOID_PTR pInitArgs)
 {
   CK_RV err;
+	
+#ifdef HAVE_W32_SYSTEM
+  WSADATA wsadat;
+
+  WSAStartup (0x202, &wsadat);
+#endif
 
   /* This is one of the few functions which do not need to take the
      global lock.  */
 
-  /* Set the assuan error source, so that gpg_error_t becomes a valid
-     substitute for assuan_error_t.  */
-  assuan_set_assuan_err_source (GPG_ERR_SOURCE_ANY);
+  assuan_set_gpg_err_source (GPG_ERR_SOURCE_ANY);
 
   _scute_debug_init ();
 
